pub enum PageExtractionMethod {
StructureTree,
Heuristic,
}Expand description
The method used for extracting content from a page.
Variants
StructureTree
Content was extracted using the PDF structure tree (tagged PDF).
Heuristic
Content was extracted using heuristic analysis of text objects.