PdfDocumentVersion

Enum PdfDocumentVersion 

pub enum PdfDocumentVersion {
    Unset,
    Pdf1_0,
    Pdf1_1,
    Pdf1_2,
    Pdf1_3,
    Pdf1_4,
    Pdf1_5,
    Pdf1_6,
    Pdf1_7,
    Pdf2_0,
    Other(i32),
}
The file version of a PdfDocument.

A list of PDF file versions is available at https://en.wikipedia.org/wiki/History_of_PDF.

Variants



Unset

No version information is available. This is the case if the PdfDocument was created via a call to Pdfium::create_new_pdf() rather than loaded from a file.



Pdf1_0

PDF 1.0, first published in 1993, supported by Acrobat Reader Carousel (1.0) onwards.



Pdf1_1

PDF 1.1, first published in 1994, supported by Acrobat Reader 2.0 onwards.



Pdf1_2

PDF 1.2, first published in 1996, supported by Acrobat Reader 3.0 onwards.



Pdf1_3

PDF 1.3, first published in 2000, supported by Acrobat Reader 4.0 onwards.



Pdf1_4

PDF 1.4, first published in 2001, supported by Acrobat Reader 5.0 onwards.



Pdf1_5

PDF 1.5, first published in 2003, supported by Acrobat Reader 6.0 onwards.



Pdf1_6

PDF 1.6, first published in 2004, supported by Acrobat Reader 7.0 onwards.



Pdf1_7

PDF 1.7, first published in 2006, supported by Acrobat Reader 8.0 onwards, adopted as ISO open standard 32000-1 in 2008. Certain proprietary Adobe extensions to PDF 1.7 are only fully supported in Acrobat Reader X (10.0) and later.



Pdf2_0

PDF 2.0, first published in 2017, ISO open standard 32000-2.



Other(i32)

A two-digit raw file version number. For instance, a value of 21 would indicate PDF version 2.1, a value of 34 would indicate PDF version 3.4, and so on. Only used when the file version number is not directly recognized by pdfium-render.

Implementations

Source

impl PdfDocumentVersion

pub const DEFAULT_VERSION: PdfDocumentVersion = PdfDocumentVersion::Pdf1_7

The default PdfDocumentVersion applied to new documents.