PdfiumCustomFontProviderRequest

Struct PdfiumCustomFontProviderRequest 

pub struct PdfiumCustomFontProviderRequest {
    pub font_face: String,
    pub character_set: PdfFontCharacterSet,
    pub weight: PdfFontWeight,
    pub is_italic: bool,
    pub is_fixed_pitch: bool,
    pub is_serif: bool,
    pub is_cursive: bool,
}
A single custom font lookup request from Pdfium.

Fields

font_face: String

The font face of the requested custom font.

character_set: PdfFontCharacterSet

The character set of the requested custom font.

weight: PdfFontWeight

The weight of the requested custom font.

is_italic: bool

true if the glyphs in the requested custom font should include dominant vertical strokes that are slanted.

is_fixed_pitch: bool

true if all the glyphs in the requested custom font should have the same width.

is_serif: bool

true if the glyphs in the requested custom font should have serifs - short strokes drawn at an angle on the top or bottom of glyph stems to decorate the glyphs. For example, Times New Roman is a serif font.

is_cursive: bool

true if the glyphs in the requested custom font should be designed to resemble cursive handwriting.