PdfCatalog

Struct PdfCatalog 

pub struct PdfCatalog<'a> { /* private fields */ }
The internal catalog properties for a single PdfDocument.

Implementations

Source

impl<'a> PdfCatalog<'a>

pub fn is_tagged(&self) -> bool

Returns true if the containing PdfDocument is a tagged PDF.

A PDF is considered “tagged” if it includes structural elements and metadata that can be used to facilitate content extraction and processing by tooling; in other words, the PDF contains data above and beyond that required merely for rendering.

For more information on tagged PDFs, see The PDF Reference, Sixth Edition, section 10.7, starting on page 883.

pub fn get_language(&self) -> Result<String, PdfiumError>

Returns the language set in the catalog of the containing PdfDocument, if any.

pub fn set_language( &mut self, language: impl ToString, ) -> Result<(), PdfiumError>

Sets the language of the containing PdfDocument to the given value.