PdfLine

Struct PdfLine 

pub struct PdfLine<'a> {
    pub alignment: PdfLineAlignment,
    pub bottom: PdfPoints,
    pub left: PdfPoints,
    pub width: PdfPoints,
    pub fragments: Vec<PdfParagraphFragment<'a>>,
}
A span of paragraph fragments that make up one line in a PdfParagraph.

Fields

alignment: PdfLineAlignment

The alignment of this line within the paragraph.

bottom: PdfPoints

The bottom Y position of this line in PDF points.

left: PdfPoints

The left X position of this line in PDF points.

width: PdfPoints

The width of this line in PDF points.

fragments: Vec<PdfParagraphFragment<'a>>

The fragments composing this line.