PdfLink

Struct PdfLink 

pub struct PdfLink<'a> { /* private fields */ }
A single link contained within a PdfPage or a PdfPageAnnotation.

Each link may have a corresponding [PdfAction] that will be triggered when the user interacts with the link, and a [PdfDestination] that indicates the target of any behaviour triggered by the [PdfAction].

Implementations

Source

impl<'a> PdfLink<'a>

pub fn bindings(&self) -> &'a dyn PdfiumLibraryBindings

Returns the PdfiumLibraryBindings used by this PdfLink.

pub fn action(&self) -> Option<PdfAction<'a>>

Returns the [PdfAction] associated with this PdfLink, if any.

The action indicates the behaviour that will occur when the user interacts with the link in a PDF viewer. For most links, this will be a local navigation action of type [PdfActionType::GoToDestinationInSameDocument], but the PDF file format supports a variety of other actions.

pub fn destination(&self) -> Option<PdfDestination<'a>>

Returns the [PdfDestination] associated with this PdfLink, if any.

The destination specifies the page and region, if any, that will be the target of any behaviour that will occur when the user interacts with the link in a PDF viewer.

pub fn rect(&self) -> Result<PdfRect, PdfiumError>

Returns the area on the page that the user can use to interact with this PdfLink in a PDF viewer, if any.