pub struct PdfPageStructureTree<'a> { /* private fields */ }Expand description
The root element of a tree of elements that together describe the logical hierarchy of a single PdfPage.
More information on the structure tree can be found in The PDF Reference, Sixth Edition, in Section 10.6.1, beginning on page 856.