PdfRect

Struct PdfRect 

pub struct PdfRect { /* private fields */ }
A rectangle measured in PdfPoints.

The coordinate space of a PdfPage has its origin (0,0) at the bottom left of the page, with x values increasing as coordinates move horizontally to the right and y values increasing as coordinates move vertically up.

Implementations

Source

impl PdfRect

pub const ZERO: PdfRect

A PdfRect object with the identity value (0.0, 0.0, 0.0, 0.0).

pub const MAX: PdfRect

A PdfRect object that encloses the entire addressable PdfPage coordinate space of ([-PdfPoints::MAX], [-PdfPoints::MAX], PdfPoints::MAX, PdfPoints::MAX).

pub const fn new( bottom: PdfPoints, left: PdfPoints, top: PdfPoints, right: PdfPoints, ) -> Self

Creates a new PdfRect object from the given PdfPoints measurements.

The coordinate space of a PdfPage has its origin (0,0) at the bottom left of the page, with x values increasing as coordinates move horizontally to the right and y values increasing as coordinates move vertically up.

pub const fn new_from_values( bottom: f32, left: f32, top: f32, right: f32, ) -> Self

Creates a new PdfRect object from the given raw points values.

The coordinate space of a PdfPage has its origin (0,0) at the bottom left of the page, with x values increasing as coordinates move horizontally to the right and y values increasing as coordinates move vertically up.

pub const fn zero() -> Self

Creates a new PdfRect object with all values set to 0.0.

Consider using the compile-time constant value PdfRect::ZERO rather than calling this function directly.

pub const fn left(&self) -> PdfPoints

Returns the left-most extent of this PdfRect.

pub const fn right(&self) -> PdfPoints

Returns the right-most extent of this PdfRect.

pub const fn bottom(&self) -> PdfPoints

Returns the bottom-most extent of this PdfRect.

pub const fn top(&self) -> PdfPoints

Returns the top-most extent of this PdfRect.

pub fn width(&self) -> PdfPoints

Returns the width of this PdfRect.

pub fn height(&self) -> PdfPoints

Returns the height of this PdfRect.

pub fn contains(&self, x: PdfPoints, y: PdfPoints) -> bool

Returns true if the given point lies inside this PdfRect.

pub fn contains_x(&self, x: PdfPoints) -> bool

Returns true if the given horizontal coordinate lies inside this PdfRect.

pub fn contains_y(&self, y: PdfPoints) -> bool

Returns true if the given vertical coordinate lies inside this PdfRect.

pub fn is_inside(&self, other: &PdfRect) -> bool

Returns true if the bounds of this PdfRect lie entirely within the given rectangle.

pub fn does_overlap(&self, other: &PdfRect) -> bool

Returns true if the bounds of this PdfRect lie at least partially within the given rectangle.

pub fn transform(&self, matrix: PdfMatrix) -> PdfRect

Returns the result of applying the given PdfMatrix to each corner point of this PdfRect.

pub fn to_quad_points(&self) -> PdfQuadPoints

Returns the PdfQuadPoints quadrilateral representation of this PdfRect.