pub type FPDF_LIBRARY_CONFIG = FPDF_LIBRARY_CONFIG_;Expand description
Process-wide options for initializing the library.
Aliased Type
#[repr(C)]pub struct FPDF_LIBRARY_CONFIG {
pub version: i32,
pub m_pUserFontPaths: *mut *const i8,
pub m_pIsolate: *mut c_void,
pub m_v8EmbedderSlot: u32,
pub m_pPlatform: *mut c_void,
pub m_RendererType: u32,
pub m_FontLibraryType: u32,
}Fields
version: i32Version number of the interface. Currently must be 2. Support for version 1 will be deprecated in the future.
m_pUserFontPaths: *mut *const i8Array of paths to scan in place of the defaults when using built-in FXGE font loading code. The array is terminated by a NULL pointer. The Array may be NULL itself to use the default paths. May be ignored entirely depending upon the platform.
m_pIsolate: *mut c_voidPointer to the v8::Isolate to use, or NULL to force PDFium to create one.
m_v8EmbedderSlot: u32The embedder data slot to use in the v8::Isolate to store PDFium’s per-isolate data. The value needs to be in the range [0, |v8::Internals::kNumIsolateDataLots|). Note that 0 is fine for most embedders.
m_pPlatform: *mut c_voidPointer to the V8::Platform to use.
m_RendererType: u32Explicit specification of 2D graphics rendering library to use. |m_RendererType| must be a valid value for |FPDF_LIBRARY_CONFIG| versions of this level or higher, or else the initialization will fail with an immediate crash. Note that use of a specified |FPDF_RENDERER_TYPE| value for which the corresponding 2D graphics rendering library is not included in the build will similarly fail with an immediate crash.
m_FontLibraryType: u32Explicit specification of font library to use when |m_RendererType| is set to |FPDF_RENDERERTYPE_SKIA|. |m_FontLibraryType| must be a valid value for |FPDF_LIBRARY_CONFIG| versions of this level or higher, or else the initialization will fail with an immediate crash. Note that use of a specified |FPDF_FONT_BACKEND_TYPE| value for which the corresponding font library is not included in the build will similarly fail with an immediate crash.