pub type PdfAttachmentIndex = u16;Expand description
The zero-based index of a single attachment inside its containing PdfAttachments collection.
pub type PdfAttachmentIndex = u16;The zero-based index of a single attachment inside its containing PdfAttachments collection.