pub struct PdfSignature<'a> { /* private fields */ }
A single digital signature in a PdfDocument.

Implementations

Returns the PdfiumLibraryBindings used by this PdfSignature.

Returns the raw byte data for this PdfSignature.

For public key signatures, the byte data is either a DER-encoded PKCS#1 binary or a DER-encoded PKCS#7 binary.

Returns the reason for the signing, if any, as a plain text description provided by the creator of this PdfSignature.

Returns the date, if any, in plain text format as specified by the creator of this PdfSignature. The format of the returned value is expected to be D:YYYYMMDDHHMMSS+XX’YY’, with precision to the second and including timezone information.

This value should only be used if the date of signing is not encoded into the digital signature itself.