PdfiumCustomFontProviderResponse

Struct PdfiumCustomFontProviderResponse 

pub struct PdfiumCustomFontProviderResponse {
    pub id: PdfiumCustomFontHandle,
    pub font_face: String,
    pub character_set: PdfFontCharacterSet,
    pub data: Vec<u8>,
}
The response to a single custom font lookup request from Pdfium.

Fields

id: PdfiumCustomFontHandle

A unique ID for the custom font provided in this response. Pdfium will use this value as a font handle in all subsequent calls related to this font.

font_face: String

The font face of the custom font provided in this response.

character_set: PdfFontCharacterSet

The character set of the custom font provided in this response.

data: Vec<u8>

The raw font byte data for the custom font provided in this response, in either OpenType or TrueType format.