pub struct PdfLine<'a> {
pub alignment: PdfLineAlignment,
pub bottom: PdfPoints,
pub left: PdfPoints,
pub width: PdfPoints,
pub fragments: Vec<PdfParagraphFragment<'a>>,
}Expand description
A span of paragraph fragments that make up one line in a PdfParagraph.
Fields
alignment: PdfLineAlignmentThe alignment of this line within the paragraph.
bottom: PdfPointsThe bottom Y position of this line in PDF points.
left: PdfPointsThe left X position of this line in PDF points.
width: PdfPointsThe width of this line in PDF points.
fragments: Vec<PdfParagraphFragment<'a>>The fragments composing this line.