pub struct PdfPageObjectMark<'a> { /* private fields */ }Expand description
A content marker identifying one or more PdfPageObject objects as “elements of interest” to a particular application or extension. Content markers can be used to attach metadata to single objects or groups of objects, and to organize rendered page objects into logical groupings or associations that may not necessarily be displayed during rendering but may have special significance to a processing application.
More information on content markers and PDF’s concept of “marked content” in general in The PDF Reference, Sixth Edition, in Section 10.5, beginning on page 850.