pub struct PdfiumConfig { /* private fields */ }Expand description
Configuration options for initializing the Pdfium library.
Implementations
Sourceimpl PdfiumConfig
impl PdfiumConfig
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new PdfiumConfig with default settings.
Sourcepub fn set_user_font_paths(self, paths: Vec<String>) -> Self
pub fn set_user_font_paths(self, paths: Vec<String>) -> Self
Sets the paths to scan for fonts in addition to the default system paths.
This is useful when you want to use custom fonts that are not installed on the system.
Sourcepub fn set_font_provider(self, fonts: Vec<FontDescriptor>) -> Self
pub fn set_font_provider(self, fonts: Vec<FontDescriptor>) -> Self
Sets a custom font provider with pre-loaded font data.
This bypasses all filesystem scanning and serves fonts directly from memory. Fonts are matched by family name, weight, italic style, and charset.
Example
use pdfium_render::prelude::*;
use std::sync::Arc;
let fonts = vec![
FontDescriptor {
family: "Arial".to_string(),
weight: 400,
is_italic: false,
charset: 0,
data: Arc::from(std::fs::read("/fonts/Arial.ttf")?),
},
];
let config = PdfiumConfig::new()
.set_font_provider(fonts);Trait Implementations
Sourceimpl Clone for PdfiumConfig
impl Clone for PdfiumConfig
Sourcefn clone(&self) -> PdfiumConfig
fn clone(&self) -> PdfiumConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PdfiumConfig
impl Debug for PdfiumConfig
Sourceimpl Default for PdfiumConfig
impl Default for PdfiumConfig
Sourcefn default() -> PdfiumConfig
fn default() -> PdfiumConfig
Returns the “default value” for a type. Read more