pub struct PdfiumLibraryConfig { /* private fields */ }Implementations
Sourceimpl PdfiumLibraryConfig
impl PdfiumLibraryConfig
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new PdfiumLibraryConfig object with all settings initialized to their default values.
Sourcepub fn clear_user_font_paths(self) -> Self
pub fn clear_user_font_paths(self) -> Self
Clears any user-specified paths that should be interrogated by Pdfium when attempting to load custom fonts.
Sourcepub fn set_platform_default_user_font_paths(self) -> Self
pub fn set_platform_default_user_font_paths(self) -> Self
Sets the list of user-specified paths that should be interrogated by Pdfium when attempting to load custom fonts to the Linux system defaults.
Sourcepub fn set_user_font_paths(self, paths: &[&str]) -> Result<Self, PdfiumError>
pub fn set_user_font_paths(self, paths: &[&str]) -> Result<Self, PdfiumError>
Sets the user-specified paths that should be interrogated by Pdfium when attempting to load custom fonts.
Sourcepub unsafe fn set_v8_isolate_ptr(self, ptr: *mut c_void) -> Self
pub unsafe fn set_v8_isolate_ptr(self, ptr: *mut c_void) -> Self
Sets the pointer to the v8::Isolate to use. If NULL, Pdfium will create one.
Sourcepub unsafe fn set_v8_embedder_slot(self, idx: c_uint) -> Self
pub unsafe fn set_v8_embedder_slot(self, idx: c_uint) -> Self
Sets the embedder data slot to use in the v8::Isolate to store Pdfium’s per-isolate
data. The value needs to be in the range [0, v8::Internals::kNumIsolateDataLots).
Note that 0 is fine for most embedders.
Sourcepub unsafe fn set_v8_platform_ptr(self, ptr: &mut c_void) -> Self
pub unsafe fn set_v8_platform_ptr(self, ptr: &mut c_void) -> Self
Sets the pointer to the v8::Platform to use.
Sourcepub fn set_renderer_anti_grain_geometry(self) -> Self
pub fn set_renderer_anti_grain_geometry(self) -> Self
Sets Pdfium’s graphics renderer to the Anti-Grain Geometry library, https://sourceforge.net/projects/agg/.
Sourcepub fn set_renderer_skia(self) -> Self
pub fn set_renderer_skia(self) -> Self
Sets Pdfium’s graphics renderer to Skia, https://skia.org/.
Sourcepub fn set_font_backend_freetype(self) -> Self
pub fn set_font_backend_freetype(self) -> Self
Sets Pdfium’s font handler to FreeType, https://freetype.org/.
Sourcepub fn set_font_backend_fontations(self) -> Self
pub fn set_font_backend_fontations(self) -> Self
Sets Pdfium’s font handler to Fontations, https://github.com/googlefonts/fontations/.