pub type FX_FILEAVAIL = _FX_FILEAVAIL;Expand description
Interface for checking whether sections of the file are available.
Aliased Type
#[repr(C)]pub struct FX_FILEAVAIL {
pub version: i32,
pub IsDataAvail: Option<unsafe extern "C" fn(*mut _FX_FILEAVAIL, usize, usize) -> i32>,
}Fields
version: i32Version number of the interface. Must be 1.
IsDataAvail: Option<unsafe extern "C" fn(*mut _FX_FILEAVAIL, usize, usize) -> i32>Reports if the specified data section is currently available. A section is available if all bytes in the section are available.
Interface Version: 1 Implementation Required: Yes
pThis - pointer to the interface structure. offset - the offset of the data section in the file. size - the size of the data section.
Returns true if the specified data section at |offset| of |size| is available.