Struct pdfium_render::signature::PdfSignature
source · pub struct PdfSignature<'a> { /* private fields */ }Expand description
A single digital signature in a PdfDocument.
Implementations
sourceimpl<'a> PdfSignature<'a>
impl<'a> PdfSignature<'a>
sourcepub fn bindings(&self) -> &'a dyn PdfiumLibraryBindings
pub fn bindings(&self) -> &'a dyn PdfiumLibraryBindings
Returns the PdfiumLibraryBindings used by this PdfSignature.
sourcepub fn bytes(&self) -> Vec<u8>
pub fn bytes(&self) -> Vec<u8>
Returns the raw byte data for this PdfSignature.
For public key signatures, the byte data is either a DER-encoded PKCS#1 binary or a DER-encoded PKCS#7 binary.
sourcepub fn reason(&self) -> Option<String>
pub fn reason(&self) -> Option<String>
Returns the reason for the signing, if any, as a plain text description provided by the creator of this PdfSignature.
sourcepub fn signing_date(&self) -> Option<String>
pub fn signing_date(&self) -> Option<String>
Returns the date, if any, in plain text format as specified by the creator of this PdfSignature. The format of the returned value is expected to be D:YYYYMMDDHHMMSS+XX’YY’, with precision to the second and including timezone information.
This value should only be used if the date of signing is not encoded into the digital signature itself.